/*-----------------------------------------------------------------
  All code is provided for EDUCATIONAL purposes ONLY. There is no
  warranty and no support.

  Copyright (c) Jack Botner and licensed under the MIT license; see
  http://opensource.org/licenses/mit-license.php

  nokia timer by Jack Botner

  main.h
  
  20201102 Fix sluggish rotary encoder response
  20211215 Move encoder processing to main
-----------------------------------------------------------------*/
#ifndef _APPLTIMER_H_
#define _APPLTIMER_H_

#include "common.h"

#undef DIAGNOSTICS       // define for testing

#define INIT_TIMER1			( 65536 - 10417 )
#define INIT_TIMER2			( 256 - 250 )

#define MAX_CHECKS       	5		// number of tests before a switch is debounced

#define EEPROM_BASE       10    // EEPROM base address
// System modes bits
#define MODE_RUN			1
#define MODE_PROGRAM		2

// Main Menu Indexes
#define INDEX_RUN			0
#define INDEX_ACTIVATE		1
#define INDEX_SETCLK		2
#define INDEX_SETON			3
#define INDEX_SETOFF		4
#define INDEX_PREPGM		5
#define INDEX_CLKTEST		6

// Events bits
#define EVENT_DEBOUNCE_IO               0
#define EVENT_ANALYZE_STATE		1
#define EVENT_READ_RTC			2
#define EVENT_UPDATE_EEPROM		3
#define EVENT_BUTTON_PRESSED	        4
#define EVENT_ENCODER_UP		5
#define EVENT_ENCODER_DOWN		6

// De-bounced switches bits
#define ENC_SWITCH_A			0
#define ENC_SWITCH_B			1
#define ENC_SWITCH_PB			2

// Rotary encoder port defines
#define ENCODER_PORT			PINC
#define ENCODER_A				  PINC1
#define ENCODER_B				  PINC0
#define ENC_SW_PORT				PINC
#define ENC_SW_PB				PINC2

// Relay port defines
#define RELAY_PORT_OUT		PORTD
#define RELAY_PORT_IN			PIND
#define RELAY_PIN				  PORTD5

// LED port defines
#define TIMER_LED_PORT			PORTC
#define TIMER1_PORT_OUT			PORTC5
#define TIMER2_PORT_OUT			PORTC4

// Program Time parameters
#define ONTIME				1
#define OFFTIME				2

// EEPROM stuff
typedef struct _MY_EEPROM_DATA
{
  uint8_t	ucOnTimeHH;				    // timer 2 parameters
  uint8_t	ucOnTimeMM;
  uint8_t	ucOffTimeHH;
  uint8_t	ucOffTimeMM;
  uint8_t ucDayofWeek;          // 0=all days, 1= Sunday, etc.
  uint8_t	ucTimer2Enabled;			// timer2 is activated
  uint8_t ucTimer1Enabled;			// timer1 preset program is active
}
MY_EEPROM_DATA;

// Functions

void encoder(void);
void main_menu(void);
#ifdef DIAGNOSTICS
void diagnostics(void);
#endif

#endif  //_MAIN_H_
